(defun efs/org-mode-setup ()
  "Properly set faces for `org-mode'."
  (org-indent-mode 1)
  (variable-pitch-mode 1)
  (visual-line-mode 1)

  ;; Ensure that anything that should be fixed-pitch in Org files appears that way
  (set-face-attribute 'org-block nil    :foreground nil :inherit 'fixed-pitch)
  (set-face-attribute 'org-table nil			:inherit 'fixed-pitch)
  (set-face-attribute 'org-formula nil			:inherit 'fixed-pitch)
  (set-face-attribute 'org-code nil			:inherit '(shadow fixed-pitch))
  (set-face-attribute 'org-table nil			:inherit '(shadow fixed-pitch))
  (set-face-attribute 'org-verbatim nil			:inherit '(shadow fixed-pitch))
  (set-face-attribute 'org-special-keyword nil		:inherit '(font-lock-comment-face fixed-pitch))
  (set-face-attribute 'org-meta-line nil		:inherit '(font-lock-comment-face fixed-pitch))
  (set-face-attribute 'org-checkbox nil			:inherit 'fixed-pitch)
  (set-face-attribute 'org-macro nil			:inherit 'fixed-pitch)
  (set-face-attribute 'line-number nil			:inherit 'fixed-pitch)
  (set-face-attribute 'line-number-current-line nil	:inherit 'fixed-pitch)

  ;; Set faces for heading levels
  (dolist (face '((org-level-1 . 1.5)
		  (org-level-2 . 1.3)
		  (org-level-3 . 1.0)
		  (org-level-4 . 1.0)
		  (org-level-5 . 1.0)
		  (org-level-6 . 1.0)
		  (org-level-7 . 1.0)
		  (org-level-8 . 1.0)))
    (set-face-attribute (car face) nil :font "Free Sans" :weight 'regular :height (cdr face)))

  ;; Make the background of code blocks slightly darker
  (set-face-attribute 'org-block nil		:background "#e6e9ef")
  (set-face-attribute 'org-block-begin-line nil :background "#e6e9ef")
  (set-face-attribute 'org-block-end-line nil	:background "#e6e9ef"))

(use-package org
  :init
  (add-hook 'org-mode-hook 'efs/org-mode-setup)
  :custom
  (org-edit-src-content-indentation 0)
  (org-src-tab-acts-natively t)
  (org-src-preserve-indentation t)
  (org-ellipsis " ▾")
  (org-todo-keywords '((sequence "TODO(t)" "NEXT(n)" "|" "DONE(d!)")))
  (org-structure-template-alist '(("c" . "src C")
				  ("el" . "src emacs-lisp")
				  ("sh" . "src shell")
				  ("a" . "export ascii")
				  ("center" . "center")
				  ("comment" . "comment")
				  ("e" . "example")
				  ("h" . "export html")
				  ("l" . "export latex")
				  ("q" . "quote")
				  ("s" . "src")))
  :config
  ;; This is needed as of Org 9.2
  ;; (require 'org-tempo)
  (set-face-attribute 'org-ellipsis nil :underline nil)
  (add-to-list 'org-src-lang-modes '("conf-unix" . conf-unix))
  (org-babel-do-load-languages
   'org-babel-load-languages
   '((emacs-lisp . t)
     (C . t)
     (shell . t))))

(use-package org-superstar
  :init
  (add-hook 'org-mode-hook 'org-superstar-mode)
  :custom
  (org-superstar-remove-leading-stars t)
  (org-superstar-headline-bullets-list '("α" "β" "γ" "δ" "ε" "ζ" "η")))

(use-package visual-fill-column
  :init
  (defun tr/visual-fill-column-setup ()
    "Set up `visual-fill-column-mode'."
    (setq-local visual-fill-column-width 80
		visual-fill-column-center-text t)
    (visual-fill-column-mode 1))
  (add-hook 'org-mode-hook 'tr/visual-fill-column-setup)
  (add-hook 'markdown-mode-hook 'tr/visual-fill-column-setup)
  (defun tr/wrapping-mode ()
    "Set wrapping for current buffer."
    (interactive)
    (set-fill-column 80)
    (toggle-word-wrap 1)
    (visual-fill-column-mode 1)))

(use-package org-make-toc
  :init
  (add-hook 'org-mode-hook 'org-make-toc-mode))

(use-package htmlize)
